@@ -12,7 +12,7 @@ package Jedi::Plugin::Session::Backend::Redis;
 
 use strict;
 use warnings;
-our $VERSION = '0.03';    # VERSION
+our $VERSION = '0.04';    # VERSION
 use Time::Duration::Parse;
 use Sereal qw/encode_sereal decode_sereal/;
 use Redis;
@@ -63,7 +63,7 @@ sub set {
     return if !defined $uuid;
     my $session = encode_sereal($value);
     $self->_redis->set( $self->prefix . $uuid, $session );
-    $self->_redis->expire( $uuid, $self->expires_in );
+    $self->_redis->expire( $self->prefix . $uuid, $self->expires_in );
     return 1;
 }
 
@@ -79,7 +79,7 @@ Jedi::Plugin::Session::Backend::Redis - Backend storage for Redis
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 BUGS
 
