@@ -8,11 +8,11 @@
 #
 package Jedi::Plugin::Session::Role::Redis;
 
-# ABSTRACT: Memory Backend
+# ABSTRACT: Redis Backend
 
 use strict;
 use warnings;
-our $VERSION = '0.03';    # VERSION
+our $VERSION = '0.04';    # VERSION
 
 use Jedi::Plugin::Session::Backend::Redis;
 use Moo::Role;
@@ -20,10 +20,10 @@ use Moo::Role;
 sub _build__jedi_session {
     my ($self)     = @_;
     my $class      = ref $self;
-    my $expires_in = $self->jedi_config->{$class}{session_expiration}
+    my $expires_in = $self->jedi_config->{$class}{session}{expiration}
         // '3 hours';
-    my $redis_config = $self->jedi_config->{$class}{redis_config};
-    my $redis_prefix = $self->jedi_config->{$class}{redis_prefix};
+    my $redis_config = $self->jedi_config->{$class}{session}{redis}{config};
+    my $redis_prefix = $self->jedi_config->{$class}{session}{redis}{prefix};
     return Jedi::Plugin::Session::Backend::Redis->new(
         config     => $redis_config,
         expires_in => $expires_in,
@@ -39,11 +39,11 @@ __END__
 
 =head1 NAME
 
-Jedi::Plugin::Session::Role::Redis - Memory Backend
+Jedi::Plugin::Session::Role::Redis - Redis Backend
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 BUGS
 
